pub struct Item {
pub timestamp: SystemTime,
pub severity: Severity,
pub body: String,
pub attributes: BTreeMap<String, String>,
pub resource: BTreeMap<String, String>,
pub trace_id: Option<String>,
pub span_id: Option<String>,
}
body: String
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.